@@ -1,7 +1,7 @@
 package Yars::Client;
 
 # ABSTRACT: Yet Another RESTful-Archive Service Client
-our $VERSION = '1.09'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 use strict;
 use warnings;
@@ -171,7 +171,7 @@ sub download {
                 WARN "Error : $msg (may retry)";
                 next;
             }
-            WARN "Error (may retry) : $msg";
+            WARN "Error (may retry) : " . (ref($msg) ? Dumper($msg) : $msg);
             next;
         };
         DEBUG "Received asset with size ".$res->content->asset->size;
@@ -440,17 +440,19 @@ sub remote {
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Yars::Client - Yet Another RESTful-Archive Service Client
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =head1 SYNOPSIS
 
@@ -529,7 +531,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
